# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: EntryProtocol.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='EntryProtocol.proto',
  package='com.alibaba.otter.canal.protocol',
  syntax='proto3',
  serialized_options=_b('\n com.alibaba.otter.canal.protocolB\nCanalEntryH\001'),
  serialized_pb=_b('\n\x13\x45ntryProtocol.proto\x12 com.alibaba.otter.canal.protocol\"\xac\x01\n\x05\x45ntry\x12\x38\n\x06header\x18\x01 \x01(\x0b\x32(.com.alibaba.otter.canal.protocol.Header\x12@\n\tentryType\x18\x02 \x01(\x0e\x32+.com.alibaba.otter.canal.protocol.EntryTypeH\x00\x12\x12\n\nstoreValue\x18\x03 \x01(\x0c\x42\x13\n\x11\x65ntryType_present\"\xc3\x03\n\x06Header\x12\x11\n\x07version\x18\x01 \x01(\x05H\x00\x12\x13\n\x0blogfileName\x18\x02 \x01(\t\x12\x15\n\rlogfileOffset\x18\x03 \x01(\x03\x12\x10\n\x08serverId\x18\x04 \x01(\x03\x12\x14\n\x0cserverenCode\x18\x05 \x01(\t\x12\x13\n\x0b\x65xecuteTime\x18\x06 \x01(\x03\x12<\n\nsourceType\x18\x07 \x01(\x0e\x32&.com.alibaba.otter.canal.protocol.TypeH\x01\x12\x12\n\nschemaName\x18\x08 \x01(\t\x12\x11\n\ttableName\x18\t \x01(\t\x12\x13\n\x0b\x65ventLength\x18\n \x01(\x03\x12@\n\teventType\x18\x0b \x01(\x0e\x32+.com.alibaba.otter.canal.protocol.EventTypeH\x02\x12\x35\n\x05props\x18\x0c \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\x12\x0c\n\x04gtid\x18\r \x01(\tB\x11\n\x0fversion_presentB\x14\n\x12sourceType_presentB\x13\n\x11\x65ventType_present\"\xe3\x01\n\x06\x43olumn\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0f\n\x07sqlType\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05isKey\x18\x04 \x01(\x08\x12\x0f\n\x07updated\x18\x05 \x01(\x08\x12\x10\n\x06isNull\x18\x06 \x01(\x08H\x00\x12\x35\n\x05props\x18\x07 \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\x12\r\n\x05value\x18\x08 \x01(\t\x12\x0e\n\x06length\x18\t \x01(\x05\x12\x11\n\tmysqlType\x18\n \x01(\tB\x10\n\x0eisNull_present\"\xc1\x01\n\x07RowData\x12?\n\rbeforeColumns\x18\x01 \x03(\x0b\x32(.com.alibaba.otter.canal.protocol.Column\x12>\n\x0c\x61\x66terColumns\x18\x02 \x03(\x0b\x32(.com.alibaba.otter.canal.protocol.Column\x12\x35\n\x05props\x18\x03 \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\"\xad\x02\n\tRowChange\x12\x0f\n\x07tableId\x18\x01 \x01(\x03\x12@\n\teventType\x18\x02 \x01(\x0e\x32+.com.alibaba.otter.canal.protocol.EventTypeH\x00\x12\x0f\n\x05isDdl\x18\n \x01(\x08H\x01\x12\x0b\n\x03sql\x18\x0b \x01(\t\x12;\n\x08rowDatas\x18\x0c \x03(\x0b\x32).com.alibaba.otter.canal.protocol.RowData\x12\x35\n\x05props\x18\r \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\x12\x15\n\rddlSchemaName\x18\x0e \x01(\tB\x13\n\x11\x65ventType_presentB\x0f\n\risDdl_present\"\x87\x01\n\x10TransactionBegin\x12\x13\n\x0b\x65xecuteTime\x18\x01 \x01(\x03\x12\x15\n\rtransactionId\x18\x02 \x01(\t\x12\x35\n\x05props\x18\x03 \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\x12\x10\n\x08threadId\x18\x04 \x01(\x03\"s\n\x0eTransactionEnd\x12\x13\n\x0b\x65xecuteTime\x18\x01 \x01(\x03\x12\x15\n\rtransactionId\x18\x02 \x01(\t\x12\x35\n\x05props\x18\x03 \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\"\"\n\x04Pair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t*}\n\tEntryType\x12\x1d\n\x19\x45NTRYTYPECOMPATIBLEPROTO2\x10\x00\x12\x14\n\x10TRANSACTIONBEGIN\x10\x01\x12\x0b\n\x07ROWDATA\x10\x02\x12\x12\n\x0eTRANSACTIONEND\x10\x03\x12\r\n\tHEARTBEAT\x10\x04\x12\x0b\n\x07GTIDLOG\x10\x05*\xe5\x01\n\tEventType\x12\x1d\n\x19\x45VENTTYPECOMPATIBLEPROTO2\x10\x00\x12\n\n\x06INSERT\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06\x43REATE\x10\x04\x12\t\n\x05\x41LTER\x10\x05\x12\t\n\x05\x45RASE\x10\x06\x12\t\n\x05QUERY\x10\x07\x12\x0c\n\x08TRUNCATE\x10\x08\x12\n\n\x06RENAME\x10\t\x12\n\n\x06\x43INDEX\x10\n\x12\n\n\x06\x44INDEX\x10\x0b\x12\x08\n\x04GTID\x10\x0c\x12\x0c\n\x08XACOMMIT\x10\r\x12\x0e\n\nXAROLLBACK\x10\x0e\x12\x0e\n\nMHEARTBEAT\x10\x0f*B\n\x04Type\x12\x18\n\x14TYPECOMPATIBLEPROTO2\x10\x00\x12\n\n\x06ORACLE\x10\x01\x12\t\n\x05MYSQL\x10\x02\x12\t\n\x05PGSQL\x10\x03\x42\x30\n com.alibaba.otter.canal.protocolB\nCanalEntryH\x01\x62\x06proto3')
)

_ENTRYTYPE = _descriptor.EnumDescriptor(
  name='EntryType',
  full_name='com.alibaba.otter.canal.protocol.EntryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENTRYTYPECOMPATIBLEPROTO2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONBEGIN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROWDATA', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONEND', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GTIDLOG', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1707,
  serialized_end=1832,
)
_sym_db.RegisterEnumDescriptor(_ENTRYTYPE)

EntryType = enum_type_wrapper.EnumTypeWrapper(_ENTRYTYPE)
_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='com.alibaba.otter.canal.protocol.EventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENTTYPECOMPATIBLEPROTO2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INSERT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALTER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERASE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRUNCATE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RENAME', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CINDEX', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DINDEX', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GTID', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XACOMMIT', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XAROLLBACK', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MHEARTBEAT', index=15, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1835,
  serialized_end=2064,
)
_sym_db.RegisterEnumDescriptor(_EVENTTYPE)

EventType = enum_type_wrapper.EnumTypeWrapper(_EVENTTYPE)
_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='com.alibaba.otter.canal.protocol.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPECOMPATIBLEPROTO2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORACLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MYSQL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PGSQL', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2066,
  serialized_end=2132,
)
_sym_db.RegisterEnumDescriptor(_TYPE)

Type = enum_type_wrapper.EnumTypeWrapper(_TYPE)
ENTRYTYPECOMPATIBLEPROTO2 = 0
TRANSACTIONBEGIN = 1
ROWDATA = 2
TRANSACTIONEND = 3
HEARTBEAT = 4
GTIDLOG = 5
EVENTTYPECOMPATIBLEPROTO2 = 0
INSERT = 1
UPDATE = 2
DELETE = 3
CREATE = 4
ALTER = 5
ERASE = 6
QUERY = 7
TRUNCATE = 8
RENAME = 9
CINDEX = 10
DINDEX = 11
GTID = 12
XACOMMIT = 13
XAROLLBACK = 14
MHEARTBEAT = 15
TYPECOMPATIBLEPROTO2 = 0
ORACLE = 1
MYSQL = 2
PGSQL = 3



_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='com.alibaba.otter.canal.protocol.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='com.alibaba.otter.canal.protocol.Entry.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entryType', full_name='com.alibaba.otter.canal.protocol.Entry.entryType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storeValue', full_name='com.alibaba.otter.canal.protocol.Entry.storeValue', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entryType_present', full_name='com.alibaba.otter.canal.protocol.Entry.entryType_present',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=58,
  serialized_end=230,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='com.alibaba.otter.canal.protocol.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='com.alibaba.otter.canal.protocol.Header.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logfileName', full_name='com.alibaba.otter.canal.protocol.Header.logfileName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logfileOffset', full_name='com.alibaba.otter.canal.protocol.Header.logfileOffset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverId', full_name='com.alibaba.otter.canal.protocol.Header.serverId', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverenCode', full_name='com.alibaba.otter.canal.protocol.Header.serverenCode', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executeTime', full_name='com.alibaba.otter.canal.protocol.Header.executeTime', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceType', full_name='com.alibaba.otter.canal.protocol.Header.sourceType', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schemaName', full_name='com.alibaba.otter.canal.protocol.Header.schemaName', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tableName', full_name='com.alibaba.otter.canal.protocol.Header.tableName', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventLength', full_name='com.alibaba.otter.canal.protocol.Header.eventLength', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventType', full_name='com.alibaba.otter.canal.protocol.Header.eventType', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.Header.props', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gtid', full_name='com.alibaba.otter.canal.protocol.Header.gtid', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='version_present', full_name='com.alibaba.otter.canal.protocol.Header.version_present',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='sourceType_present', full_name='com.alibaba.otter.canal.protocol.Header.sourceType_present',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='eventType_present', full_name='com.alibaba.otter.canal.protocol.Header.eventType_present',
      index=2, containing_type=None, fields=[]),
  ],
  serialized_start=233,
  serialized_end=684,
)


_COLUMN = _descriptor.Descriptor(
  name='Column',
  full_name='com.alibaba.otter.canal.protocol.Column',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='com.alibaba.otter.canal.protocol.Column.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sqlType', full_name='com.alibaba.otter.canal.protocol.Column.sqlType', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='com.alibaba.otter.canal.protocol.Column.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isKey', full_name='com.alibaba.otter.canal.protocol.Column.isKey', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated', full_name='com.alibaba.otter.canal.protocol.Column.updated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isNull', full_name='com.alibaba.otter.canal.protocol.Column.isNull', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.Column.props', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.otter.canal.protocol.Column.value', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='com.alibaba.otter.canal.protocol.Column.length', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mysqlType', full_name='com.alibaba.otter.canal.protocol.Column.mysqlType', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='isNull_present', full_name='com.alibaba.otter.canal.protocol.Column.isNull_present',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=687,
  serialized_end=914,
)


_ROWDATA = _descriptor.Descriptor(
  name='RowData',
  full_name='com.alibaba.otter.canal.protocol.RowData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='beforeColumns', full_name='com.alibaba.otter.canal.protocol.RowData.beforeColumns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='afterColumns', full_name='com.alibaba.otter.canal.protocol.RowData.afterColumns', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.RowData.props', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=917,
  serialized_end=1110,
)


_ROWCHANGE = _descriptor.Descriptor(
  name='RowChange',
  full_name='com.alibaba.otter.canal.protocol.RowChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tableId', full_name='com.alibaba.otter.canal.protocol.RowChange.tableId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventType', full_name='com.alibaba.otter.canal.protocol.RowChange.eventType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isDdl', full_name='com.alibaba.otter.canal.protocol.RowChange.isDdl', index=2,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sql', full_name='com.alibaba.otter.canal.protocol.RowChange.sql', index=3,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowDatas', full_name='com.alibaba.otter.canal.protocol.RowChange.rowDatas', index=4,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.RowChange.props', index=5,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ddlSchemaName', full_name='com.alibaba.otter.canal.protocol.RowChange.ddlSchemaName', index=6,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='eventType_present', full_name='com.alibaba.otter.canal.protocol.RowChange.eventType_present',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='isDdl_present', full_name='com.alibaba.otter.canal.protocol.RowChange.isDdl_present',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=1113,
  serialized_end=1414,
)


_TRANSACTIONBEGIN = _descriptor.Descriptor(
  name='TransactionBegin',
  full_name='com.alibaba.otter.canal.protocol.TransactionBegin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executeTime', full_name='com.alibaba.otter.canal.protocol.TransactionBegin.executeTime', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactionId', full_name='com.alibaba.otter.canal.protocol.TransactionBegin.transactionId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.TransactionBegin.props', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='threadId', full_name='com.alibaba.otter.canal.protocol.TransactionBegin.threadId', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1417,
  serialized_end=1552,
)


_TRANSACTIONEND = _descriptor.Descriptor(
  name='TransactionEnd',
  full_name='com.alibaba.otter.canal.protocol.TransactionEnd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executeTime', full_name='com.alibaba.otter.canal.protocol.TransactionEnd.executeTime', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactionId', full_name='com.alibaba.otter.canal.protocol.TransactionEnd.transactionId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.TransactionEnd.props', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1554,
  serialized_end=1669,
)


_PAIR = _descriptor.Descriptor(
  name='Pair',
  full_name='com.alibaba.otter.canal.protocol.Pair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.otter.canal.protocol.Pair.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.otter.canal.protocol.Pair.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1705,
)

_ENTRY.fields_by_name['header'].message_type = _HEADER
_ENTRY.fields_by_name['entryType'].enum_type = _ENTRYTYPE
_ENTRY.oneofs_by_name['entryType_present'].fields.append(
  _ENTRY.fields_by_name['entryType'])
_ENTRY.fields_by_name['entryType'].containing_oneof = _ENTRY.oneofs_by_name['entryType_present']
_HEADER.fields_by_name['sourceType'].enum_type = _TYPE
_HEADER.fields_by_name['eventType'].enum_type = _EVENTTYPE
_HEADER.fields_by_name['props'].message_type = _PAIR
_HEADER.oneofs_by_name['version_present'].fields.append(
  _HEADER.fields_by_name['version'])
_HEADER.fields_by_name['version'].containing_oneof = _HEADER.oneofs_by_name['version_present']
_HEADER.oneofs_by_name['sourceType_present'].fields.append(
  _HEADER.fields_by_name['sourceType'])
_HEADER.fields_by_name['sourceType'].containing_oneof = _HEADER.oneofs_by_name['sourceType_present']
_HEADER.oneofs_by_name['eventType_present'].fields.append(
  _HEADER.fields_by_name['eventType'])
_HEADER.fields_by_name['eventType'].containing_oneof = _HEADER.oneofs_by_name['eventType_present']
_COLUMN.fields_by_name['props'].message_type = _PAIR
_COLUMN.oneofs_by_name['isNull_present'].fields.append(
  _COLUMN.fields_by_name['isNull'])
_COLUMN.fields_by_name['isNull'].containing_oneof = _COLUMN.oneofs_by_name['isNull_present']
_ROWDATA.fields_by_name['beforeColumns'].message_type = _COLUMN
_ROWDATA.fields_by_name['afterColumns'].message_type = _COLUMN
_ROWDATA.fields_by_name['props'].message_type = _PAIR
_ROWCHANGE.fields_by_name['eventType'].enum_type = _EVENTTYPE
_ROWCHANGE.fields_by_name['rowDatas'].message_type = _ROWDATA
_ROWCHANGE.fields_by_name['props'].message_type = _PAIR
_ROWCHANGE.oneofs_by_name['eventType_present'].fields.append(
  _ROWCHANGE.fields_by_name['eventType'])
_ROWCHANGE.fields_by_name['eventType'].containing_oneof = _ROWCHANGE.oneofs_by_name['eventType_present']
_ROWCHANGE.oneofs_by_name['isDdl_present'].fields.append(
  _ROWCHANGE.fields_by_name['isDdl'])
_ROWCHANGE.fields_by_name['isDdl'].containing_oneof = _ROWCHANGE.oneofs_by_name['isDdl_present']
_TRANSACTIONBEGIN.fields_by_name['props'].message_type = _PAIR
_TRANSACTIONEND.fields_by_name['props'].message_type = _PAIR
DESCRIPTOR.message_types_by_name['Entry'] = _ENTRY
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Column'] = _COLUMN
DESCRIPTOR.message_types_by_name['RowData'] = _ROWDATA
DESCRIPTOR.message_types_by_name['RowChange'] = _ROWCHANGE
DESCRIPTOR.message_types_by_name['TransactionBegin'] = _TRANSACTIONBEGIN
DESCRIPTOR.message_types_by_name['TransactionEnd'] = _TRANSACTIONEND
DESCRIPTOR.message_types_by_name['Pair'] = _PAIR
DESCRIPTOR.enum_types_by_name['EntryType'] = _ENTRYTYPE
DESCRIPTOR.enum_types_by_name['EventType'] = _EVENTTYPE
DESCRIPTOR.enum_types_by_name['Type'] = _TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
  DESCRIPTOR = _ENTRY,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Entry)
  ))
_sym_db.RegisterMessage(Entry)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
  DESCRIPTOR = _HEADER,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Header)
  ))
_sym_db.RegisterMessage(Header)

Column = _reflection.GeneratedProtocolMessageType('Column', (_message.Message,), dict(
  DESCRIPTOR = _COLUMN,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Column)
  ))
_sym_db.RegisterMessage(Column)

RowData = _reflection.GeneratedProtocolMessageType('RowData', (_message.Message,), dict(
  DESCRIPTOR = _ROWDATA,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.RowData)
  ))
_sym_db.RegisterMessage(RowData)

RowChange = _reflection.GeneratedProtocolMessageType('RowChange', (_message.Message,), dict(
  DESCRIPTOR = _ROWCHANGE,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.RowChange)
  ))
_sym_db.RegisterMessage(RowChange)

TransactionBegin = _reflection.GeneratedProtocolMessageType('TransactionBegin', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONBEGIN,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.TransactionBegin)
  ))
_sym_db.RegisterMessage(TransactionBegin)

TransactionEnd = _reflection.GeneratedProtocolMessageType('TransactionEnd', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONEND,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.TransactionEnd)
  ))
_sym_db.RegisterMessage(TransactionEnd)

Pair = _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), dict(
  DESCRIPTOR = _PAIR,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Pair)
  ))
_sym_db.RegisterMessage(Pair)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
